@@ -429,7 +429,9 @@ function build_record_form(widget_name, grid, index_map) {
             }
             dojo.create('br', null, widget_div);
             var wid = zc.dojo.widgets[rc_wid.widget_constructor](
-                rc_wid, dojo.create('div', {style: 'height: auto;'}, widget_div), order);
+                rc_wid,
+                dojo.create('div', {style: 'height: auto;'}, widget_div),
+                order);
             edit_dlg.form_widgets.push(wid);
         }
     });
